Session

Struct Session 

pub struct Session { /* private fields */ }
A WebTransport Session, able to accept/create streams and send/recv datagrams.

The session can be cloned to create multiple handles, which is which no method is &mut. The session will be closed with on drop.

Implementations

Source

impl Session

pub async fn accept_uni(&self) -> Result<RecvStream, Error>

Block until the peer creates a new unidirectional stream.

Won’t return None unless the connection is closed.

pub async fn accept_bi(&self) -> Result<(SendStream, RecvStream), Error>

Block until the peer creates a new bidirectional stream.

pub async fn open_bi(&self) -> Result<(SendStream, RecvStream), Error>

Open a new bidirectional stream, which may block when there are too many concurrent streams.

pub async fn open_uni(&self) -> Result<SendStream, Error>

Open a new unidirectional stream, which may block when there are too many concurrent streams.

pub async fn send_datagram(&self, payload: Bytes) -> Result<(), Error>

Send a datagram over the network.

QUIC datagrams may be dropped for any reason:

  • Network congestion.
  • Random packet loss.
  • Payload is larger than max_datagram_size()
  • Peer is not receiving datagrams.
  • Peer has too many outstanding datagrams.
  • ???
pub async fn max_datagram_size(&self) -> usize

The maximum size of a datagram that can be sent.

pub async fn recv_datagram(&self) -> Result<Bytes, Error>

Receive a datagram over the network.

pub fn close(&self, code: u32, reason: &str)

Close the connection immediately with a code and reason.

pub async fn closed(&self) -> Error

Block until the connection is closed.

pub fn url(&self) -> Option<&Url>

Return the URL used to create the session, or None for a raw QUIC session established without an HTTP/3 CONNECT request.

pub fn protocol(&self) -> Option<&str>

Return the application protocol used to create the session.

For a WebTransport session this is the negotiated subprotocol; for a raw QUIC session it is the negotiated ALPN.